@@ -16,35 +16,28 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-# This script deletes IP alias(es) inside VE  used dist. Archlinux.
-#
-# For usage info see ve-alias_del(5) man page.
-#
-# Parameters are passed in environment variables.
-# Required parameters:
-#   IP_ADDR       - IPs to delete, several addresses should be divided by space
-# Optional parameters:
-#   VE_STATE      - state of VE; could be one of:
-#                     starting | stopping | running | stopped
+# Deletes IP address(es) from a container running Archlinux.
+
 VENET_DEV=venet0
 CFGFILE=/etc/rc.conf
 
 function del_ip()
 {
 	local ifname
-	local ip
-	
+	local ipm
+
 	echo ${IP_ADDR}
-	for ip in ${IP_ADDR}; do
-		ifname=`grep -B 1 -e "\\<${ip}\\>" ${CFGFILE} | \
-			    grep "${VENET_DEV}_" | cut -d'=' -f1`
+	for ipm in ${IP_ADDR}; do
+		ip_conv $ipm
+		ifname=`grep -B 1 -e "\\<${_IP}\\>" ${CFGFILE} |
+			grep "${VENET_DEV}_" | cut -d'=' -f1`
 		if [ -n "${ifname}" ]; then
 		    # shutdown interface venet0_x
 		    /etc/rc.d/network ifdown ${ifname} 2> /dev/null
 
 		    # remove venet0_x from cfg
 		    del_param "${CFGFILE}" "${ifname}"
-			
+
 		    # del venet0_x from INTERFACES array
 		    del_param3 "${CFGFILE}" "INTERFACES" "${ifname}"
 		fi
