@@ -1,5 +1,5 @@
-#!/bin/bash
-#  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+#!/bin/sh
+#  Copyright (C) 2000-2011, Parallels, Inc. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -16,27 +16,28 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-# This script runnning on HN and perform next postinstall tasks:
-# 1. Randomizes crontab for given VE so all crontab tasks
-#  of all VEs will not start at the same time.
+# runs on the host system and performs these postinstall tasks:
+# 1. Randomizes crontab for given container so all crontab tasks
+#    of all containers will not start at the same time.
 # 2. Disables root password if it is empty.
-#
+# 3. Seeds /etc/hosts with localhost entries for IPv4 and IPv6
+# 4. Creates empty /etc/resolv.conf
 
-function randcrontab()
+randcrontab()
 {
-	file=${VE_ROOT}"/etc/crontab"
+	local file
+	for file in ${VE_ROOT}/etc/crontab ${VE_ROOT}/etc/cron.d/*; do
+		[ -f "${file}" ] || continue
 
-	[ -f "${file}" ] || return 0
-
-	/bin/cp -fp ${file} ${file}.$$
-	cat ${file} | awk '
+		/bin/cp -fp ${file} ${file}.$$
+		cat ${file} | awk '
 BEGIN { srand(); }
 {
 	if ($0 ~ /^[ \t]*#/ || $0 ~ /^[ \t]+*$/) {
 		print $0;
-        	next;
+		next;
 	}
-	if ((n = split($0, ar, /[ \t]/)) < 7) {
+	if ((n = split($0, ar)) < 7) {
 		print $0;
 		next;
 	}
@@ -60,14 +61,14 @@ BEGIN { srand(); }
 		line = line " "  ar[i];
 	}
 	print line;
-}
-' > ${file}.$$ && /bin/mv -f ${file}.$$ ${file}
-	/bin/rm -f ${file}.$$ 2>/dev/null
+}' >		${file}.$$ && /bin/mv -f ${file}.$$ ${file}
+		/bin/rm -f ${file}.$$ 2>/dev/null
+	done
 }
 
-function disableroot()
+disableroot()
 {
-	file=${VE_ROOT}"/etc/passwd"
+	local file=${VE_ROOT}"/etc/passwd"
 
 	[ -f "$file" ] || return 0
 
@@ -78,8 +79,27 @@ function disableroot()
 	fi
 }
 
-[ -z "${VE_ROOT}" ] && return 1
+set_network()
+{
+	local file=${VE_ROOT}"/etc/hosts"
+	if ! grep -qw '127.0.0.1' ${file} 2>/dev/null; then
+		echo '127.0.0.1 localhost.localdomain localhost' >> ${file}
+	fi
+	if ! grep -qw '::1' ${file} 2>/dev/null; then
+		echo "::1 localhost.localdomain localhost" >> ${file}
+	fi
+
+	# Some distros' network scripts emit ugly warnings about non-existing
+	# /etc/resolv.conf, so it won't hurt to create an empty one
+	file=${VE_ROOT}"/etc/resolv.conf"
+	if [ ! -e "${file}" ]; then
+		touch ${file}
+	fi
+}
+
+[ -z "${VE_ROOT}" ] && exit 1
 randcrontab
 disableroot
+set_network
 
 exit 0
