@@ -32,7 +32,17 @@ function get_aliases()
 	IFNUMLIST=`grep -e "^LABEL_" ${IFCFG} | sed 's/^LABEL_\(.*\)=.*/\1/'`
 }
 
-function init()
+# Fix a bug in sles9 ifup-route script
+function fix_ifup_route()
+{
+	local file=/etc/sysconfig/network/scripts/ifup-route
+	local str='run_iproute $ACTION to $TYPE $DEST via $GWAY $IFACE $IPOPTS'
+	if grep -q "$str" $file; then
+		sed -i -e "/$str/s/via \$GWAY/\${GWAY:+via \$GWAY}/" $file
+	fi
+}
+
+function init_config()
 {
 
 	mkdir -p ${IFCFG_DIR}
@@ -41,21 +51,17 @@ BOOTPROTO=static
 BROADCAST=0.0.0.0
 NETMASK=255.255.255.255
 IPADDR=127.0.0.1" > ${IFCFG} ||
-	error "Can't write to file ${IFCFG_DIR}/${VENET_DEV_CFG}" ${VZ_FS_NO_DISK_SPACE}
+	error "Can't write to file ${IFCFG}" ${VZ_FS_NO_DISK_SPACE}
 
-	remove_fake_old_route ${ROUTES}
-	if ! grep -q -E "${FAKEGATEWAYNET}[[:space:]]0.0.0.0[[:space:]]255.255.255.0[[:space:]]${VENET_DEV}" ${ROUTES} 2>/dev/null;
-	then
-		echo "${FAKEGATEWAYNET}	0.0.0.0 255.255.255.0	${VENET_DEV}" >> ${ROUTES}
-	fi
-	if ! grep -q -E "default[[:space:]]${FAKEGATEWAY}[[:space:]]0.0.0.0[[:space:]]${VENET_DEV}" ${ROUTES} 2>/dev/null;
-	then
-		echo "default ${FAKEGATEWAY}	0.0.0.0	${VENET_DEV}" >> ${ROUTES}
-	fi
 	# Set up /etc/hosts
 	if [ ! -f ${HOSTFILE} ]; then
 		echo "127.0.0.1 localhost.localdomain localhost" > $HOSTFILE
 	fi
+	cat << EOF > ${ROUTES}
+default - - ${VENET_DEV}
+default :: - ${VENET_DEV}
+EOF
+	fix_ifup_route
 }
 
 function create_config()
@@ -65,24 +71,28 @@ function create_config()
 
 	echo "IPADDR_${ifnum}=${ip}
 LABEL_${ifnum}=${ifnum}" >> ${IFCFG} ||
-	error "Can't write to file ${IFCFG_DIR}/${VENET_DEV_CFG}" ${VZ_FS_NO_DISK_SPACE}
+	error "Can't write to file ${IFCFG}" ${VZ_FS_NO_DISK_SPACE}
 }
 
 function add_ip()
 {
-	local ip
+	local ipm
 	local ifnum=-1
+	local found
 
-	if [ "x${IPDELALL}" = "xyes" -o "x${VE_STATE}" = "xstarting" ]; then
-		rm -f ${IFCFG} 2>/dev/null
-	fi
-	if [ ! -f "${IFCFG}" ]; then
-		init
+	if [ "x${VE_STATE}" = "xstarting" ]; then
+		init_config
+	elif [ "x${IPDELALL}" = "xyes" ]; then
+		init_config
+	elif [ ! -f "${IFCFG}" ]; then
+		init_config
 	fi
+
 	get_aliases
-	for ip in ${IP_ADDR}; do
+	for ipm in ${IP_ADDR}; do
+		ip_conv $ipm
 		found=
-		if grep -q -w "${ip}" ${IFCFG}; then
+		if grep -q -w "${_IP}" ${IFCFG}; then
 			continue
 		fi
 		while test -z ${found}; do
@@ -91,7 +101,7 @@ function add_ip()
 				found=1
 			fi
 		done
-		create_config ${ip} ${ifnum}
+		create_config ${_IP} ${ifnum}
 	done
 	if [ "x${VE_STATE}" = "xrunning" ]; then
 		ifdown $VENET_DEV  >/dev/null 2>&1
