@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,13 +21,18 @@
 #include "types.h"
 #include "quota.h"
 
-#define MNT_DETACH		0x00000002
+#ifndef MNT_DETACH
+# define MNT_DETACH		0x00000002
+#endif
+
 /** Action script prefixes.
  */
 #define MOUNT_PREFIX		"mount"
 #define UMOUNT_PREFIX		"umount"
 #define START_PREFIX		"start"
 #define STOP_PREFIX		"stop"
+#define PRE_MOUNT_PREFIX	"premount"
+#define POST_UMOUNT_PREFIX	"postumount"
 
 #define DESTR_PREFIX		"destroyed"
 
@@ -49,7 +54,7 @@ typedef struct {
  *			 0 - CT unmounted.
  *			-1 - error
  */
-int vps_is_mounted(char *root);
+int vps_is_mounted(const char *root);
 
 /** Mount CT.
  *
@@ -78,7 +83,7 @@ int vps_mount(vps_handler *h, envid_t veid, fs_param *fs, dq_param *dq,
  * @param root		CT root.
  * @return		0 on success.
  */
-int fsumount(envid_t veid, char *root);
+int fsumount(envid_t veid, const char *root);
 
 /** Unmount CT and run unmount action script if exists.
  *
@@ -88,12 +93,12 @@ int fsumount(envid_t veid, char *root);
  * @param skip		skip unmount action scrips
  * @return		0 on success.
  */
-int vps_umount(vps_handler *h, envid_t veid, char *root, skipFlags skip);
+int vps_umount(vps_handler *h, envid_t veid, const char *root, skipFlags skip);
 
 int vps_set_fs(fs_param *g_fs, fs_param *fs);
 
 extern const char *vz_fs_get_name();
-extern int vz_fs_is_mounted(char *root);
+extern int vz_fs_is_mounted(const char *root);
 extern int vz_mount(fs_param *fs, int remount);
 
 #endif
