@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -61,6 +61,7 @@ static struct ubname2id {
 	{"DCACHESIZE",	PARAM_DCACHESIZE},
 	{"NUMIPTENT",	PARAM_NUMIPTENT},
 	{"AVNUMPROC",	PARAM_AVNUMPROC},
+	{"SWAPPAGES",	PARAM_SWAPPAGES},
 	{NULL, 0},
 };
 
@@ -75,7 +76,7 @@ int check_ub(ub_param *ub)
 
 #define CHECK_UB(name)							\
 if (ub->name == NULL) {							\
-	logger(-1, 0, "UB parameter " #name " not set");			\
+	logger(-1, 0, "Error: required UB parameter " #name " not set");\
 	ret = VZ_NOTENOUGHUBCPARAMS;					\
 }
 
@@ -128,6 +129,7 @@ inline static int is_ub_empty(ub_param *ub)
 	CHECK_UB(numfile)
 	CHECK_UB(dcachesize)
 	CHECK_UB(numiptent)
+	CHECK_UB(swappages)
 #undef CHECK_UB
 
 	return 1;
@@ -143,7 +145,7 @@ int get_ub_resid(char *name)
 	return -1;
 }
 
-const char *get_ub_name(int res_id)
+const char *get_ub_name(unsigned int res_id)
 {
 	int i;
 
@@ -185,6 +187,16 @@ if (ub->name != NULL) {							\
 	SET_UB_LIMIT(numfile, UB_NUMFILE)
 	SET_UB_LIMIT(dcachesize, UB_DCACHESIZE)
 	SET_UB_LIMIT(numiptent, UB_IPTENTRIES)
+	if (ub->swappages &&
+	    setublimit(veid, UB_SWAPPAGES, ub->swappages) == -1)
+	{
+		if (errno == EINVAL) {
+			logger(-1, ENOSYS, "failed to set swappages");
+		} else {
+			logger(-1, errno, "failed to set swappages");
+			return VZ_SETUBC_ERROR;
+		}
+	}
 #undef SET_UB_LIMIT
 
 	return 0;
@@ -192,8 +204,8 @@ if (ub->name != NULL) {							\
 
 /** Apply UBC resources.
  *
- * @param h		VE handler.
- * @param veid		VE id.
+ * @param h		CT handler.
+ * @param veid		CT ID.
  * @param ubc		UBC parameters
  * @return		0 on success
  */
@@ -205,18 +217,18 @@ int vps_set_ublimit(vps_handler *h, envid_t veid, ub_param *ub)
 		return 0;
 	if (!vps_is_run(h, veid)) {
 		logger(-1, 0, "Unable to apply UBC parameters: "
-			"VE is not running");
+			"container is not running");
 		return VZ_VE_NOT_RUNNING;
 	}
 	if ((ret = set_ublimit(h, veid, ub)))
 		return ret;
-	logger(-1, 0, "UB limits were set successefully");
+	logger(-1, 0, "UB limits were set successfully");
 	return 0;
 }
 
 void free_ub_param(ub_param *ub)
 {
-#define FREE_P(x) if (ub->x != NULL) {free(ub->x); ub->x = NULL;}
+#define FREE_P(x) free(ub->x); ub->x = NULL;
 	if (ub == NULL)
 		return;
 	FREE_P(kmemsize)
@@ -240,6 +252,7 @@ void free_ub_param(ub_param *ub)
 	FREE_P(dcachesize)
 	FREE_P(numiptent)
 	FREE_P(avnumproc)
+	FREE_P(swappages)
 #undef FREE_P
 }
 
@@ -272,6 +285,7 @@ if (res_id == id) {						\
 	ADD_UB_PARAM(dcachesize, PARAM_DCACHESIZE)
 	ADD_UB_PARAM(numiptent, PARAM_NUMIPTENT)
 	ADD_UB_PARAM(avnumproc, PARAM_AVNUMPROC)
+	ADD_UB_PARAM(swappages, PARAM_SWAPPAGES)
 #undef ADD_UB_PARAM
 }
 
@@ -299,9 +313,9 @@ int add_ub_param(ub_param *ub, ub_res *res)
 void merge_ub(ub_param *dst, ub_param *src)
 {
 #define MERGE_P2(x)						\
-if ((src->x) != NULL) { 					\
-	if ((dst->x) == NULL) 					\
-		dst->x = malloc(sizeof(*(dst->x)) * 2);	 	\
+if ((src->x) != NULL) {						\
+	if ((dst->x) == NULL)					\
+		dst->x = malloc(sizeof(*(dst->x)) * 2);		\
 	dst->x[0] = src->x[0];					\
 	dst->x[1] = src->x[1];					\
 }
@@ -327,12 +341,13 @@ if ((src->x) != NULL) { 					\
 	MERGE_P2(dcachesize)
 	MERGE_P2(numiptent)
 	MERGE_P2(avnumproc)
+	MERGE_P2(swappages)
 #undef MERGE_P2
 }
 
 /** Read UBC resources current usage from /proc/user_beancounters
  *
- * @param veid		VE id.
+ * @param veid		CT ID.
  * @param ub		UBC parameters.
  * @return		0 on success.
  */
@@ -342,7 +357,8 @@ int vps_read_ubc(envid_t veid, ub_param *ub)
 	char str[STR_SIZE];
 	char name[64];
 	const char *fmt = NULL; /* make gcc happy */
-	int ret, found, id;
+	int ret, found;
+	envid_t id;
 	unsigned long held, maxheld, barrier, limit;
 	ub_res res;
 
@@ -380,4 +396,3 @@ int vps_read_ubc(envid_t veid, ub_param *ub)
 	fclose(fd);
 	return !found;
 }
-
